from prettytable import PrettyTable
import requests

class LightController:
    def __init__(self, conbee):
        self.conbee = conbee
        self.api_url = f'http://{conbee.gateway}:{conbee.port}/api/{conbee.api_key}'

    def show_all_lights(self):
        show_all_request = f'{self.api_url}/lights'
        response = requests.get(show_all_request)

        if response.ok:
            lights_data = response.json()
            self.format_and_print_lights(lights_data)
        else:
            print("Failed to retrieve lights data:", response.status_code)

    #format using prettytable
    def format_and_print_lights(self, lights_data):
        table = PrettyTable()
        table.field_names = ['ID', 'Device name', 'MAC', 'State']
        table.align = 'l'

        for light_id, light_info in lights_data.items():
            name = light_info.get('name')
            unique_id = light_info.get('uniqueid')
            color = '\033[92m●\033[0m' if light_info['state'].get('on') else '\033[91m●\033[0m'
            table.add_row([light_id, name, unique_id, color])

        print(table)

    def control_light(self, light_id, action):
        control_request = f'{self.api_url}/lights/{light_id}/state'
        control_response_headers = {'Content-Type': 'application/json'}
        if(action == 'on'):
            control_response_data = { "on": True }
        else:
            control_response_data = { "on": False }

        #request to create api key
        control_response = requests.put(control_request, json=control_response_data, headers=control_response_headers)

        if control_response.ok:
            print('Changed')
        else:
            print("Couldn't change the state of this light")



import json
import requests
import os

class Conbee:
    def __init__(self):
        self.ensure_config_exists()
        self.load_config()

    def ensure_config_exists(self):
        config_path = 'config.json'
        if not os.path.exists(config_path):
            print('Config file does not exist. Creating one...')
            self.create_config(config_path)

    def load_config(self):
        with open('config.json', 'r') as file:
            config_data = json.load(file)
        self.api_key = config_data.get('api_key')
        self.name = config_data.get('name')
        self.gateway = config_data.get('gateway')
        self.port = config_data.get('port')

    def create_config(self, config_path):
        try:
            discover_response = requests.get('https://phoscon.de/discover')
            discover_response.raise_for_status()
            conbee_data = discover_response.json()
            
            if not isinstance(conbee_data, list) or not conbee_data:
                raise ValueError("Received data is not in the expected format.")

            #fill the values from the autodiscover
            config_data = {
                'name': conbee_data[0].get('name'),
                'gateway': conbee_data[0].get('internalipaddress'),
                'port': conbee_data[0].get('internalport', 80) 
            }

            #Generate User's API key
            def wait_for_enter():
                print("Press Enter once you click 'Authenticate App' on your dashboard")
                input()
            
            #wait for user to click the authenticate button
            wait_for_enter()
            api_response_headers = {'Content-Type': 'application/json'}
            api_response_data = { "devicetype": "huex" }
            api_response_url = f"http://{config_data['gateway']}:{config_data['port']}/api"

            #request to create api key
            api_response = requests.post(api_response_url, json=api_response_data, headers=api_response_headers)

            if api_response.ok:
                api_data = api_response.json()
                config_data['api_key'] = api_data[0]['success'].get('username')
                with open(config_path, 'w') as file:
                    json.dump(config_data, file)
                    print(f"Config file created at {config_path}")
            else:
                #print("Error:", api_response.status_code)
                if api_response.status_code == 403:
                    print('The Authenticate App button was not pressed.')

        except requests.RequestException as e:
            print(f"Error retrieving data: {e}")
        except ValueError as e:
            print(f"Data format error: {e}")
        except IOError as e:
            print(f"Error writing to {config_path}")



import argparse
from .light_controller import LightController
from .conbee import Conbee

def main():
    parser = argparse.ArgumentParser(description="Huex CLI Tool")
    subparsers = parser.add_subparsers(dest="command")

    # Subparser for 'show' command
    parser_show = subparsers.add_parser('show', help='Show all lights')

    # Subparser for 'control' command
    parser_control = subparsers.add_parser('control', help='Control a specific light')
    parser_control.add_argument('light_id', type=int, help='ID of the light to control')
    parser_control.add_argument('action', choices=['on', 'off'], help='Action to perform on the light')

    args = parser.parse_args()

    # Initialize Conbee and LightController
    conbee = Conbee()
    light_controller = LightController(conbee)

    # Execute commands based on parsed arguments
    if args.command == 'show':
        light_controller.show_all_lights()
    elif args.command == 'control':
        light_controller.control_light(args.light_id, args.action)

if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

setup(
    name='huex',
    version='0.1.2',
    author='s1lvx',
    author_email='silva@cfsilva.com',
    description='A powerful and lightweight CLI based tool for the Conbee II',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/s1lvax/huex',
    packages=find_packages(),
    install_requires=[
        'requests',
        'prettytable',
    ],
    entry_points={
        'console_scripts': [
            'huex=huex.main:main',
        ],
    },
    python_requires='>=3.6',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Utilities',
    ],
    keywords='cli conbee2 zigbee huelights hue',
)
